@@ -37,6 +37,8 @@ import gi
 gi.require_version('GLib', '2.0')  # noqa
 from gi.repository import GLib
 
+from catfish_lib import FiletypeLists
+
 try:
     gi.require_version('Zeitgeist', '2.0')
     from gi.repository import Zeitgeist
@@ -289,12 +291,11 @@ class CatfishSearchEngine:
             if " ".join(keywords) in fname.lower():
                 return True
         else:
-            match_list = set()
-            for kword in keywords:
-                if kword in fname.lower():
-                    match_list.add(kword)
-                if len(set(keywords)) == len(match_list):
-                    return True
+            fname = fname.lower()
+            for kword in set(keywords):
+                if kword not in fname:
+                    return False
+            return True
 
     def set_exact(self, exact):
         """Set method for exact"""
@@ -531,16 +532,7 @@ class CatfishSearchMethod_Fulltext(CatfishSearchMethod):
     def is_txt(self, filename):
         """Checks if text mimetype."""
         mime = str(mimetypes.guess_type(filename)[0])
-        text_list = ('ardour', 'audacity', 'desktop', 'document',
-                     'fontforge', 'java', 'json', 'm4', 'mbox',
-                     'message', 'mimearchive', 'msg', 'none', 'perl',
-                     'pgp-keys', 'php', 'postscript', 'rtf',
-                     'ruby', 'shellscript', 'spreadsheet', 'sql',
-                     'subrip', 'text', 'troff', 'url', 'winhlp',
-                     'x-bittorent', 'x-cue', 'x-extension-cfg',
-                     'x-glade', 'x-mpegurl', 'x-sami', 'x-theme',
-                     'x-trash', 'xml', 'xpixmap', 'yaml')
-        for filetype in text_list:
+        for filetype in FiletypeLists.text_list():
             if filetype in mime.lower():
                 return True
 
@@ -556,12 +548,15 @@ class CatfishSearchMethod_Fulltext(CatfishSearchMethod):
                 if " ".join(keywords) in line.lower():
                     return True
         else:
-            match_list = set()
+            keywords = list(set(keywords))
+            match_found = [False for i in range(len(keywords))]
+            match_found_count = 0
             for line in lines:
-                for kword in keywords:
-                    if kword in line.lower():
-                        match_list.add(kword)
-                if len(set(keywords)) == len(match_list):
+                for i in range(len(keywords)):
+                    if (not match_found[i]) and keywords[i] in line.lower():
+                        match_found[i] = True
+                        match_found_count += 1
+                if match_found_count == len(keywords):
                     return True
 
     def search_zip(self, z, member, keywords):
@@ -674,7 +669,7 @@ class CatfishSearchMethod_Zeitgeist(CatfishSearchMethod):
 
     def run(self, keywords, path, search_zips, regex=False, exclude_paths=[]):
         """Run the Zeitgeist SearchMethod."""
-        keywords = " ".join(keywords)
+        keywords = " ".join(keywords).lower()
         self.stop_search = False
         event_template = Zeitgeist.Event()
 
@@ -705,7 +700,7 @@ class CatfishSearchMethod_Zeitgeist(CatfishSearchMethod):
                 if uri.startswith('file://'):
                     fullname = str(uri[7:])
                     filepath, filename = os.path.split(fullname)
-                    if keywords.lower() in filename and \
+                    if keywords in filename and \
                             uri not in uniques and \
                             path in filepath:
                         uniques.append(uri)
