@@ -2,7 +2,7 @@
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 #   Catfish - a versatile file searching tool
 #   Copyright (C) 2007-2012 Christian Dywan <christian@twotoasts.de>
-#   Copyright (C) 2012-2019 Sean Davis <smd.seandavis@gmail.com>
+#   Copyright (C) 2012-2022 Sean Davis <bluesabre@xfce.org>
 #
 #   This program is free software: you can redistribute it and/or modify it
 #   under the terms of the GNU General Public License version 2, as published
@@ -16,34 +16,22 @@
 #   You should have received a copy of the GNU General Public License along
 #   with this program.  If not, see <https://www.gnu.org/licenses/>.
 
+# pylint: disable=C0413
+
 """Helpers for an Ubuntu application."""
 import logging
 import os
 import sys
 
 import gi
+gi.require_version('GObject', '2.0')  # noqa
 gi.require_version('Gtk', '3.0')  # noqa
-
-from gi.repository import Gtk, GObject
+from gi.repository import GObject, Gtk
 
 from . catfishconfig import get_data_file
 from . Builder import Builder
 
-python_version = sys.version_info[:3]
 gobject_version = GObject.pygobject_version
-gtk_version = (Gtk.get_major_version(),
-               Gtk.get_minor_version(),
-               Gtk.get_micro_version())
-
-
-def check_python_version(major_version, minor_version, micro=0):
-    """Return true if running python >= requested version"""
-    return python_version >= (major_version, minor_version, micro)
-
-
-def check_gtk_version(major_version, minor_version, micro=0):
-    """Return true if running gtk >= requested version"""
-    return gtk_version >= (major_version, minor_version, micro)
 
 
 def check_gobject_version(major_version, minor_version, micro=0):
@@ -51,6 +39,16 @@ def check_gobject_version(major_version, minor_version, micro=0):
     return gobject_version >= (major_version, minor_version, micro)
 
 
+def xdg_current_desktop():
+    desktop = os.environ.get("ORIGINAL_XDG_CURRENT_DESKTOP", None)
+    if desktop is None:
+        desktop = os.environ.get("XDG_CURRENT_DESKTOP", "")
+    desktop = desktop.lower()
+    if desktop == "ubuntu:gnome":
+        return "gnome"
+    return desktop
+
+
 def get_builder(builder_file_name):
     """Return a fully-instantiated Gtk.Builder instance from specified ui file
 
@@ -138,7 +136,6 @@ def get_help_uri(page=None):
 
 def show_uri(parent, link):
     """Open the specified URI."""
-    from gi.repository import Gtk  # pylint: disable=E0611
     screen = parent.get_screen()
     Gtk.show_uri(screen, link, Gtk.get_current_event_time())
 
